# Ancient-map-tiler
This python project aims to provide tiles data for a web view of an ancient map
The source image of the map may be very large. To be usable in a web view such as Leaflet it must be splitted into tiles at different zooms
## Prerequisites
 - python (tested on 3.13)
 - poetry
## Usage
```shell
cd ancient-map-tiler
poetry install
# Download a large map from wikipedia
wget https://upload.wikimedia.org/wikipedia/commons/5/50/TabulaPeutingeriana.jpg
# Generate the tiles into a directory named tiles
poetry run make_tiles TabulaPeutingeriana.jpg -o tiles
# Open the preview in your web browser
open simple_map_preview.html
```
